@@ -73,11 +73,19 @@ class WlanDriverStatusPlugin(StatusMenuItem):
 class Notifications:
 	def __init__(self, Parent):
 		self.bus = Parent.bus
-		self.object = self.bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
-		self.interface = dbus.Interface(self.object,dbus_interface='org.freedesktop.Notifications')
 
 	def notify(self, message):
-		self.interface.SystemNoteInfoprint(message)
+		if hasattr(self, 'object') == False or hasattr(self, 'interface') == False:
+			try:
+				self.object = self.bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
+				self.interface = dbus.Interface(self.object,dbus_interface='org.freedesktop.Notifications')
+			except:
+				pass
+		if hasattr(self, 'object') and hasattr(self, 'interface'):
+			try:
+				self.interface.SystemNoteInfoprint(message)
+			except:
+				pass
 
 class Config:
 	def __init__(self):
